import { HttpClient, NonNullablePaths, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { GetReferralProgramResponse, ReferralProgram, UpdateReferralProgramResponse, ActivateReferralProgramResponse, PauseReferralProgramResponse, GetAiSocialMediaPostsSuggestionsOptions, GetAISocialMediaPostsSuggestionsResponse, GenerateAiSocialMediaPostsSuggestionsOptions, GenerateAISocialMediaPostsSuggestionsResponse, GetReferralProgramPremiumFeaturesResponse, ProgramUpdatedEnvelope } from './index.typings.js';
export { AISocialMediaPostSuggestion, Action, ActionEvent, ActivateReferralProgramRequest, App, Asset, BaseEventMetadata, BillingReference, BulkGetReferralProgramRequest, BulkGetReferralProgramResponse, CancellationDetails, ContractSwitchReason, ContractSwitchType, ContractSwitched, Coupon, CouponDiscountTypeOptionsOneOf, CouponScope, CouponScopeOrMinSubtotalOneOf, Cycle, CycleCycleSelectorOneOf, DeleteContext, DeleteStatus, DiscountType, DomainEvent, DomainEventBodyOneOf, Emails, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, FixedAmountDiscount, GenerateAISocialMediaPostsSuggestionsRequest, GetAISocialMediaPostsSuggestionsRequest, GetReferralProgramPremiumFeaturesRequest, GetReferralProgramRequest, Group, HtmlSitePublished, IdentificationData, IdentificationDataIdOneOf, Initiator, Interval, IntervalUnit, LoyaltyPoints, MessageEnvelope, MetaSiteSpecialEvent, MetaSiteSpecialEventPayloadOneOf, Namespace, NamespaceChanged, OdeditorAssigned, OdeditorUnassigned, OneTime, Page, PauseReferralProgramRequest, PercentageDiscount, PicassoAssigned, PicassoUnassigned, PremiumFeatures, PriceIncreaseTrigger, ProductAdjustment, ProductPriceIncreaseData, ProgramInSite, ProgramStatus, ProviderName, ReactivationData, ReactivationReasonEnum, RecurringChargeAttemptFailed, RecurringChargeSucceeded, RestoreInfo, Reward, RewardOptionsOneOf, ServiceProvisioned, ServiceRemoved, SiteCreated, SiteCreatedContext, SiteDeleted, SiteHardDeleted, SiteMarkedAsTemplate, SiteMarkedAsWixSite, SitePublished, SitePurgedExternally, SiteRenamed, SiteTransferred, SiteUndeleted, SiteUnpublished, SiteUrlChanged, State, StudioAssigned, StudioUnassigned, Subscription, SubscriptionAssigned, SubscriptionAutoRenewTurnedOff, SubscriptionAutoRenewTurnedOn, SubscriptionCancelled, SubscriptionCreated, SubscriptionEvent, SubscriptionEventEventOneOf, SubscriptionNearEndOfPeriod, SubscriptionPendingChange, SubscriptionStatus, SubscriptionTransferred, SubscriptionUnassigned, Type, UnassignReason, UpdateReferralProgramRequest, WebhookIdentityType } from './index.typings.js';

type ProgramNonNullablePaths = `status` | `referredFriendReward.couponOptions.fixedAmountOptions.amount` | `referredFriendReward.couponOptions.percentageOptions.percentage` | `referredFriendReward.couponOptions.minimumSubtotal` | `referredFriendReward.couponOptions.scope.namespace` | `referredFriendReward.couponOptions.scope.group.name` | `referredFriendReward.couponOptions.name` | `referredFriendReward.couponOptions.discountType` | `referredFriendReward.loyaltyPointsOptions.amount` | `referredFriendReward.type` | `referringCustomerReward.couponOptions.fixedAmountOptions.amount` | `referringCustomerReward.couponOptions.percentageOptions.percentage` | `referringCustomerReward.couponOptions.minimumSubtotal` | `referringCustomerReward.couponOptions.scope.namespace` | `referringCustomerReward.couponOptions.scope.group.name` | `referringCustomerReward.couponOptions.name` | `referringCustomerReward.couponOptions.discountType` | `referringCustomerReward.loyaltyPointsOptions.amount` | `referringCustomerReward.type` | `successfulReferralActions` | `emails.encourageToReferFriends` | `emails.notifyCustomersAboutReward` | `premiumFeatures.referralProgram`;
declare function getReferralProgram$1(httpClient: HttpClient): GetReferralProgramSignature;
interface GetReferralProgramSignature {
    /**
     * Retrieves the referral program.
     */
    (): Promise<NonNullablePaths<GetReferralProgramResponse, {
        [P in ProgramNonNullablePaths]: `referralProgram.${P}`;
    }[ProgramNonNullablePaths]>>;
}
declare function updateReferralProgram$1(httpClient: HttpClient): UpdateReferralProgramSignature;
interface UpdateReferralProgramSignature {
    /**
     * Updates a referral program. Supports partial updates.
     *
     * Revision number, which increments by 1 each time the referral program is updated.
     * To prevent conflicting changes, the current revision must be passed when updating the referral program.
     * @param - Referral program to update. Include the latest `revision` for a successful update.
     */
    (referralProgram: NonNullablePaths<ReferralProgram, `revision`>): Promise<NonNullablePaths<UpdateReferralProgramResponse, {
        [P in ProgramNonNullablePaths]: `referralProgram.${P}`;
    }[ProgramNonNullablePaths]>>;
}
declare function activateReferralProgram$1(httpClient: HttpClient): ActivateReferralProgramSignature;
interface ActivateReferralProgramSignature {
    /**
     * Activates the referral program, changing its status to `ACTIVE`.
     */
    (): Promise<NonNullablePaths<ActivateReferralProgramResponse, {
        [P in ProgramNonNullablePaths]: `referralProgram.${P}`;
    }[ProgramNonNullablePaths]>>;
}
declare function pauseReferralProgram$1(httpClient: HttpClient): PauseReferralProgramSignature;
interface PauseReferralProgramSignature {
    /**
     * Pauses the referral program, changing its status to `PAUSED`.
     */
    (): Promise<NonNullablePaths<PauseReferralProgramResponse, {
        [P in ProgramNonNullablePaths]: `referralProgram.${P}`;
    }[ProgramNonNullablePaths]>>;
}
declare function getAiSocialMediaPostsSuggestions$1(httpClient: HttpClient): GetAiSocialMediaPostsSuggestionsSignature;
interface GetAiSocialMediaPostsSuggestionsSignature {
    /**
     * Retrieves pre-generated AI social media post suggestions for promoting the referral program.
     *
     * This method returns a list of AI-generated social media post suggestions that site owners or members can use to promote the referral program. You can display these suggestions to allow referring customers to easily copy and share them on their preferred social media platforms.
     *
     * >**Note**: This method retrieves existing suggestions. To generate new ones,
     * use Generate AI Social Media Posts Suggestions.
     */
    (options?: GetAiSocialMediaPostsSuggestionsOptions): Promise<NonNullablePaths<GetAISocialMediaPostsSuggestionsResponse, `suggestions` | `suggestions.${number}.postContent`>>;
}
declare function generateAiSocialMediaPostsSuggestions$1(httpClient: HttpClient): GenerateAiSocialMediaPostsSuggestionsSignature;
interface GenerateAiSocialMediaPostsSuggestionsSignature {
    /**
     * Creates new AI-generated social media post suggestions for promoting the referral program.
     *
     * This method generates new AI-powered social media post suggestions for promoting the referral program. Use it to refresh content or create alternatives to existing suggestions.
     *
     * >**Note**: This method generates new suggestions each time it's called. To retrieve existing suggestions without generating new ones, use Get AI Social Media Posts Suggestions.
     */
    (options?: GenerateAiSocialMediaPostsSuggestionsOptions): Promise<NonNullablePaths<GenerateAISocialMediaPostsSuggestionsResponse, `suggestions` | `suggestions.${number}.postContent`>>;
}
declare function getReferralProgramPremiumFeatures$1(httpClient: HttpClient): GetReferralProgramPremiumFeaturesSignature;
interface GetReferralProgramPremiumFeaturesSignature {
    /**
     * Retrieves information about the enabled premium features for the referral program.
     */
    (): Promise<NonNullablePaths<GetReferralProgramPremiumFeaturesResponse, `referralProgram`>>;
}
declare const onProgramUpdated$1: EventDefinition<ProgramUpdatedEnvelope, "wix.loyalty.referral.v1.program_updated">;

declare const getReferralProgram: MaybeContext<BuildRESTFunction<typeof getReferralProgram$1> & typeof getReferralProgram$1>;
declare const updateReferralProgram: MaybeContext<BuildRESTFunction<typeof updateReferralProgram$1> & typeof updateReferralProgram$1>;
declare const activateReferralProgram: MaybeContext<BuildRESTFunction<typeof activateReferralProgram$1> & typeof activateReferralProgram$1>;
declare const pauseReferralProgram: MaybeContext<BuildRESTFunction<typeof pauseReferralProgram$1> & typeof pauseReferralProgram$1>;
declare const getAiSocialMediaPostsSuggestions: MaybeContext<BuildRESTFunction<typeof getAiSocialMediaPostsSuggestions$1> & typeof getAiSocialMediaPostsSuggestions$1>;
declare const generateAiSocialMediaPostsSuggestions: MaybeContext<BuildRESTFunction<typeof generateAiSocialMediaPostsSuggestions$1> & typeof generateAiSocialMediaPostsSuggestions$1>;
declare const getReferralProgramPremiumFeatures: MaybeContext<BuildRESTFunction<typeof getReferralProgramPremiumFeatures$1> & typeof getReferralProgramPremiumFeatures$1>;
/**
 * Triggered when a referral program is updated.
 */
declare const onProgramUpdated: BuildEventDefinition<typeof onProgramUpdated$1>;

export { ActivateReferralProgramResponse, GenerateAISocialMediaPostsSuggestionsResponse, GenerateAiSocialMediaPostsSuggestionsOptions, GetAISocialMediaPostsSuggestionsResponse, GetAiSocialMediaPostsSuggestionsOptions, GetReferralProgramPremiumFeaturesResponse, GetReferralProgramResponse, PauseReferralProgramResponse, ProgramUpdatedEnvelope, ReferralProgram, UpdateReferralProgramResponse, activateReferralProgram, generateAiSocialMediaPostsSuggestions, getAiSocialMediaPostsSuggestions, getReferralProgram, getReferralProgramPremiumFeatures, onProgramUpdated, pauseReferralProgram, updateReferralProgram };
