import { GetReferralProgramRequest as GetReferralProgramRequest$1, GetReferralProgramResponse as GetReferralProgramResponse$1, BulkGetReferralProgramRequest as BulkGetReferralProgramRequest$1, BulkGetReferralProgramResponse as BulkGetReferralProgramResponse$1, UpdateReferralProgramRequest as UpdateReferralProgramRequest$1, UpdateReferralProgramResponse as UpdateReferralProgramResponse$1, ActivateReferralProgramRequest as ActivateReferralProgramRequest$1, ActivateReferralProgramResponse as ActivateReferralProgramResponse$1, PauseReferralProgramRequest as PauseReferralProgramRequest$1, PauseReferralProgramResponse as PauseReferralProgramResponse$1, GetAISocialMediaPostsSuggestionsRequest as GetAISocialMediaPostsSuggestionsRequest$1, GetAISocialMediaPostsSuggestionsResponse as GetAISocialMediaPostsSuggestionsResponse$1, GenerateAISocialMediaPostsSuggestionsRequest as GenerateAISocialMediaPostsSuggestionsRequest$1, GenerateAISocialMediaPostsSuggestionsResponse as GenerateAISocialMediaPostsSuggestionsResponse$1, GetReferralProgramPremiumFeaturesRequest as GetReferralProgramPremiumFeaturesRequest$1, GetReferralProgramPremiumFeaturesResponse as GetReferralProgramPremiumFeaturesResponse$1 } from './index.typings.mjs';
import '@wix/sdk-types';

interface ReferralProgram {
    /**
     * Referral program name.
     * @minLength 2
     * @maxLength 50
     */
    name?: string | null;
    /** @readonly */
    status?: ProgramStatusWithLiterals;
    /**
     * Revision number, which increments by 1 each time the program is updated.
     * To prevent conflicting changes, the current `revision` must be passed when updating the program.
     * @immutable
     */
    revision?: string | null;
    /**
     * Date and time the program was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the program was last updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /**
     * Reward configuration for the referred friend.
     * Specifies the reward given to a new customer who was referred to the business.
     */
    referredFriendReward?: Reward;
    /**
     * Reward configuration for the referring customer.
     * Specifies the reward given to an existing customer who referred a new customer to the business.
     */
    referringCustomerReward?: Reward;
    /**
     * List of actions that complete a referral. For an action to be considered successful, the referred friend must place and pay for an item.
     * @maxSize 100
     */
    successfulReferralActions?: ActionWithLiterals[];
    /** Configures email notifications for the referral program. */
    emails?: Emails;
    /**
     * Indicates which premium features are available for the current account.
     * @readonly
     */
    premiumFeatures?: PremiumFeatures;
}
/** Status of the referral program. */
declare enum ProgramStatus {
    /** Unknown program status. */
    UNKNOWN = "UNKNOWN",
    /** Referral program is in a draft state and is being modified. It is not yet active. */
    DRAFT = "DRAFT",
    /** Referral program is active. */
    ACTIVE = "ACTIVE",
    /** Referral program is paused. */
    PAUSED = "PAUSED"
}
/** @enumType */
type ProgramStatusWithLiterals = ProgramStatus | 'UNKNOWN' | 'DRAFT' | 'ACTIVE' | 'PAUSED';
interface Reward extends RewardOptionsOneOf {
    /** Options for coupon reward type. */
    couponOptions?: Coupon;
    /** Options for the Loyalty points reward type. */
    loyaltyPointsOptions?: LoyaltyPoints;
    /** Type of the reward. */
    type?: TypeWithLiterals;
}
/** @oneof */
interface RewardOptionsOneOf {
    /** Options for coupon reward type. */
    couponOptions?: Coupon;
    /** Options for the Loyalty points reward type. */
    loyaltyPointsOptions?: LoyaltyPoints;
}
declare enum Type {
    /** Unknown reward type. */
    UNKNOWN = "UNKNOWN",
    /** Coupon reward type. */
    COUPON = "COUPON",
    /** Loyalty points reward type. */
    LOYALTY_POINTS = "LOYALTY_POINTS",
    /** No reward type. */
    NOTHING = "NOTHING"
}
/** @enumType */
type TypeWithLiterals = Type | 'UNKNOWN' | 'COUPON' | 'LOYALTY_POINTS' | 'NOTHING';
interface Coupon extends CouponDiscountTypeOptionsOneOf, CouponScopeOrMinSubtotalOneOf {
    /** Options for fixed amount discount. */
    fixedAmountOptions?: FixedAmountDiscount;
    /** Options for percentage discounts. */
    percentageOptions?: PercentageDiscount;
    /** Limit the coupon to carts with a subtotal above this number. */
    minimumSubtotal?: number;
    /** Specifies the type of line items this coupon will apply to. See [valid scope values](https://dev.wix.com/api/rest/coupons/coupons/valid-scope-values). */
    scope?: CouponScope;
    /**
     * Coupon name.
     * @minLength 1
     * @maxLength 50
     */
    name?: string;
    /** Coupon discount type. */
    discountType?: DiscountTypeWithLiterals;
    /**
     * Whether the coupon is limited to one item.
     * If `true` and a customer pays for multiple items, the discount applies to only the lowest priced item.
     * Coupons with a bookings `scope.namespace` are always limited to one item.
     */
    limitedToOneItem?: boolean | null;
    /** Whether the coupon applies to subscription products. */
    appliesToSubscriptions?: boolean | null;
    /**
     * Specifies the amount of discounted cycles for a subscription item.
     *
     * - Can only be set when `scope.namespace = pricingPlans`.
     * - If `discountedCycleCount` is empty, the coupon applies to all available cycles.
     * - `discountedCycleCount` is ignored if `appliesToSubscriptions = true`.
     *
     * Max: `999`
     */
    discountedCycleCount?: number | null;
}
/** @oneof */
interface CouponDiscountTypeOptionsOneOf {
    /** Options for fixed amount discount. */
    fixedAmountOptions?: FixedAmountDiscount;
    /** Options for percentage discounts. */
    percentageOptions?: PercentageDiscount;
}
/** @oneof */
interface CouponScopeOrMinSubtotalOneOf {
    /** Limit the coupon to carts with a subtotal above this number. */
    minimumSubtotal?: number;
    /** Specifies the type of line items this coupon will apply to. See [valid scope values](https://dev.wix.com/api/rest/coupons/coupons/valid-scope-values). */
    scope?: CouponScope;
}
declare enum DiscountType {
    /** Unknown discount type. */
    UNKNOWN = "UNKNOWN",
    /** Discount as a fixed amount. */
    FIXED_AMOUNT = "FIXED_AMOUNT",
    /** Discount as a percentage. */
    PERCENTAGE = "PERCENTAGE",
    /** Free shipping. If `true`, the coupon applies to all items in all `namespaces`. */
    FREE_SHIPPING = "FREE_SHIPPING"
}
/** @enumType */
type DiscountTypeWithLiterals = DiscountType | 'UNKNOWN' | 'FIXED_AMOUNT' | 'PERCENTAGE' | 'FREE_SHIPPING';
interface FixedAmountDiscount {
    /** Amount of the discount as a fixed value. */
    amount?: number;
}
interface PercentageDiscount {
    /**
     * Percentage of discount.
     * @max 100
     */
    percentage?: number;
}
interface CouponScope {
    /** Scope namespace (Wix Stores, Wix Bookings, Wix Events, Wix Pricing Plans) */
    namespace?: string;
    /** Coupon scope's applied group, for example, Event or ticket in Wix Events. */
    group?: Group;
}
interface Group {
    /** Name of the group. */
    name?: string;
    /** Entity ID of the group. */
    entityId?: string | null;
}
interface LoyaltyPoints {
    /**
     * Number of loyalty points to give.
     * @min 1
     * @max 9999999
     */
    amount?: number;
}
declare enum Action {
    /** Unknown action. */
    UNKNOWN = "UNKNOWN",
    /** Referred friend ordered and paid for an order in a store. */
    STORE_ORDER_PLACED = "STORE_ORDER_PLACED",
    /** Referred friend ordered and paid for a plan. */
    PLAN_ORDERED = "PLAN_ORDERED",
    /** Referred friend ordered and paid for a ticket. */
    TICKET_ORDERED = "TICKET_ORDERED",
    /** Referred friend booked and paid for a session. */
    SESSION_BOOKED = "SESSION_BOOKED",
    /** Referred friend placed and paid for a restaurant order. */
    RESTAURANT_ORDER_PLACED = "RESTAURANT_ORDER_PLACED",
    /** Referred friend joined an online program. */
    ONLINE_PROGRAM_JOINED = "ONLINE_PROGRAM_JOINED"
}
/** @enumType */
type ActionWithLiterals = Action | 'UNKNOWN' | 'STORE_ORDER_PLACED' | 'PLAN_ORDERED' | 'TICKET_ORDERED' | 'SESSION_BOOKED' | 'RESTAURANT_ORDER_PLACED' | 'ONLINE_PROGRAM_JOINED';
interface Emails {
    /** Configures email invitations to encourage customers to refer their friends. Select the apps for which this feature is enabled. */
    encourageToReferFriends?: AppWithLiterals[];
    /**
     * Whether to send email notifications to referring customers when they receive a referral reward.
     * If true, referring customers will be notified by email when their referred friend completes a qualifying action (for example, placing an order).
     */
    notifyCustomersAboutReward?: boolean;
}
declare enum App {
    /** Unknown app. */
    UNKNOWN = "UNKNOWN",
    /** Send an email to customers who've placed an order with stores. */
    STORES = "STORES",
    /** Send an email to customers who've placed an order with pricing plans. */
    PRICING_PLANS = "PRICING_PLANS",
    /** Send an email to customers who've placed an order with events. */
    EVENTS = "EVENTS",
    /** Send an email to customers who've placed an order with bookings. */
    BOOKINGS = "BOOKINGS",
    /** Send an email to customers who've placed an order with restaurants. */
    RESTAURANTS = "RESTAURANTS",
    /** Send an email to customers who've joined an online program. */
    ONLINE_PROGRAMS = "ONLINE_PROGRAMS"
}
/** @enumType */
type AppWithLiterals = App | 'UNKNOWN' | 'STORES' | 'PRICING_PLANS' | 'EVENTS' | 'BOOKINGS' | 'RESTAURANTS' | 'ONLINE_PROGRAMS';
interface PremiumFeatures {
    /**
     * Whether the site owner has access to the referral program feature.
     * @readonly
     */
    referralProgram?: boolean;
}
interface GetReferralProgramRequest {
}
interface GetReferralProgramResponse {
    /** Retrieved referral program. */
    referralProgram?: ReferralProgram;
}
interface BulkGetReferralProgramRequest {
}
interface BulkGetReferralProgramResponse {
    /** Retrieved referral programs. */
    programInSites?: ProgramInSite[];
}
interface ProgramInSite {
    /**
     * Metasite ID.
     * @format GUID
     */
    metaSiteId?: string;
    /** Retrieved referral program. */
    referralProgram?: ReferralProgram;
}
interface UpdateReferralProgramRequest {
    /** Referral program to update. Include the latest `revision` for a successful update. */
    referralProgram: ReferralProgram;
}
interface UpdateReferralProgramResponse {
    /** Updated referral program. */
    referralProgram?: ReferralProgram;
}
interface ActivateReferralProgramRequest {
}
interface ActivateReferralProgramResponse {
    /** Activated referral program. */
    referralProgram?: ReferralProgram;
}
interface PauseReferralProgramRequest {
}
interface PauseReferralProgramResponse {
    /** Paused referral program. */
    referralProgram?: ReferralProgram;
}
interface GetAISocialMediaPostsSuggestionsRequest {
    /**
     * Topic to generate social media post suggestions for. For example, fitness, education, or technology.
     * @maxLength 512
     */
    topic?: string;
}
interface GetAISocialMediaPostsSuggestionsResponse {
    /**
     * Generated social media post suggestions.
     * @maxSize 3
     */
    suggestions?: AISocialMediaPostSuggestion[];
    /**
     * Referral URL to refer friends.
     * @maxLength 2083
     */
    referFriendsPageUrl?: string | null;
}
interface AISocialMediaPostSuggestion {
    /**
     * Suggested post content.
     * @maxLength 4096
     */
    postContent?: string;
    /**
     * Suggested hashtags.
     * @maxLength 256
     * @maxSize 256
     */
    hashtags?: string[];
}
interface GenerateAISocialMediaPostsSuggestionsRequest {
    /**
     * Topic to generate social media post suggestions for. For example, fitness, education, or technology.
     * @maxLength 512
     */
    topic?: string;
}
interface GenerateAISocialMediaPostsSuggestionsResponse {
    /**
     * Generated social media post suggestions.
     * @maxSize 3
     */
    suggestions?: AISocialMediaPostSuggestion[];
    /**
     * Referral URL to refer friends.
     * @maxLength 2083
     */
    referFriendsPageUrl?: string | null;
}
interface GetReferralProgramPremiumFeaturesRequest {
}
interface GetReferralProgramPremiumFeaturesResponse {
    /**
     * Whether the site has the referral program feature enabled.
     * @readonly
     */
    referralProgram?: boolean;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function getReferralProgram(): __PublicMethodMetaInfo<'GET', {}, GetReferralProgramRequest$1, GetReferralProgramRequest, GetReferralProgramResponse$1, GetReferralProgramResponse>;
declare function bulkGetReferralProgram(): __PublicMethodMetaInfo<'GET', {}, BulkGetReferralProgramRequest$1, BulkGetReferralProgramRequest, BulkGetReferralProgramResponse$1, BulkGetReferralProgramResponse>;
declare function updateReferralProgram(): __PublicMethodMetaInfo<'PATCH', {}, UpdateReferralProgramRequest$1, UpdateReferralProgramRequest, UpdateReferralProgramResponse$1, UpdateReferralProgramResponse>;
declare function activateReferralProgram(): __PublicMethodMetaInfo<'PATCH', {}, ActivateReferralProgramRequest$1, ActivateReferralProgramRequest, ActivateReferralProgramResponse$1, ActivateReferralProgramResponse>;
declare function pauseReferralProgram(): __PublicMethodMetaInfo<'PATCH', {}, PauseReferralProgramRequest$1, PauseReferralProgramRequest, PauseReferralProgramResponse$1, PauseReferralProgramResponse>;
declare function getAiSocialMediaPostsSuggestions(): __PublicMethodMetaInfo<'GET', {}, GetAISocialMediaPostsSuggestionsRequest$1, GetAISocialMediaPostsSuggestionsRequest, GetAISocialMediaPostsSuggestionsResponse$1, GetAISocialMediaPostsSuggestionsResponse>;
declare function generateAiSocialMediaPostsSuggestions(): __PublicMethodMetaInfo<'POST', {}, GenerateAISocialMediaPostsSuggestionsRequest$1, GenerateAISocialMediaPostsSuggestionsRequest, GenerateAISocialMediaPostsSuggestionsResponse$1, GenerateAISocialMediaPostsSuggestionsResponse>;
declare function getReferralProgramPremiumFeatures(): __PublicMethodMetaInfo<'GET', {}, GetReferralProgramPremiumFeaturesRequest$1, GetReferralProgramPremiumFeaturesRequest, GetReferralProgramPremiumFeaturesResponse$1, GetReferralProgramPremiumFeaturesResponse>;

export { type __PublicMethodMetaInfo, activateReferralProgram, bulkGetReferralProgram, generateAiSocialMediaPostsSuggestions, getAiSocialMediaPostsSuggestions, getReferralProgram, getReferralProgramPremiumFeatures, pauseReferralProgram, updateReferralProgram };
